#include <Wire.h>

#define BUFFER_SIZE 25


#define ADXL343_ADDRESS                 (0x53)    // I2C ADXL343 ALT Address
#define ADXL343_REG_DATAX0              (0x32)    // X-axis data 0
#define ADXL343_REG_DATAY0              (0x34)    // Y-axis data 0
#define ADXL343_REG_DATAZ0              (0x36)    // Z-axis data 0

int i = 0;
int pb3, pb4;
char buffer[10];

uint8_t adxl343WriteRegister(uint8_t reg, uint8_t value) {
  Wire.beginTransmission(ADXL343_ADDRESS);
  Wire.write((uint8_t)reg);
  Wire.write((uint8_t)value);
  Wire.endTransmission();
}

uint8_t adxl343ReadRegister(uint8_t reg) {
  Wire.beginTransmission(ADXL343_ADDRESS);
  Wire.write((uint8_t)reg);
  Wire.endTransmission();
  Wire.requestFrom(ADXL343_ADDRESS, 1);
  return Wire.read();
}

int16_t adxl343ReadWord(uint8_t reg) {
  Wire.beginTransmission(ADXL343_ADDRESS);
  Wire.write((uint8_t)reg);
  Wire.endTransmission();
  Wire.requestFrom(ADXL343_ADDRESS, 2);
  return (uint16_t)(Wire.read() | (Wire.read() << 8));
}


void setup() {
  delay(2000);
  Serial.begin(9600);
  Serial.flush();
  Serial.print("hello_serial: starting\n");

  Wire.begin();

  uint8_t deviceId = adxl343ReadRegister(0x00);
  Serial.print(" deviceId: ");
  Serial.println(deviceId);
  
  adxl343WriteRegister(0x2D,0x08); // POWER_CTL register
  adxl343WriteRegister(0x31,0x08); // Full res register

  i = 0;
}

void loop() {
  _delay_ms(500);
  i++;

  int16_t x = adxl343ReadWord(ADXL343_REG_DATAX0);
  int16_t y = adxl343ReadWord(ADXL343_REG_DATAY0);
  int16_t z = adxl343ReadWord(ADXL343_REG_DATAZ0);

  Serial.print("x: ");
  Serial.print(x);
  Serial.print("\ty: ");
  Serial.print(y);
  Serial.print("\tz: ");
  Serial.println(z);
}

